@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Cards {
-    client: Client,
+    pub client: Client,
 }
 
 impl Cards {
@@ -22,98 +22,35 @@ impl Cards {
      * **Parameters:**
      *
      * * `authorization: &str` -- The OAuth2 token header.
-     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
-     * * `user_id: &str` -- The OAuth2 token header.
-     * * `card_program_id: &str` -- The OAuth2 token header.
+     * * `user_id: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `card_program_id: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    pub async fn get_page(
+    pub async fn get(
         &self,
-        start: &str,
+        start: uuid::Uuid,
         page_size: f64,
-        user_id: &str,
-        card_program_id: &str,
-    ) -> Result<Vec<crate::types::Card>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        if !card_program_id.is_empty() {
-            query_args.push(format!("card_program_id={}", card_program_id));
+        user_id: uuid::Uuid,
+        card_program_id: uuid::Uuid,
+    ) -> Result<crate::types::GetCardsResponse> {
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !card_program_id.to_string().is_empty() {
+            query_args.push(("card_program_id".to_string(), card_program_id.to_string()));
         }
-        query_args.push(format!("page_size={}", page_size));
-        if !start.is_empty() {
-            query_args.push(format!("start={}", start));
+        if !page_size.to_string().is_empty() {
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        if !user_id.is_empty() {
-            query_args.push(format!("user_id={}", user_id));
+        if !start.to_string().is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !user_id.to_string().is_empty() {
+            query_args.push(("user_id".to_string(), user_id.to_string()));
         }
-        let url = format!("/cards?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/cards?{}", query_);
 
-        let resp: crate::types::GetCardsResponse = self.client.get(&url, None).await.unwrap();
-
-        // Return our response data.
-        Ok(resp.cards)
-    }
-
-    /**
-     * List cards.
-     *
-     * This function performs a `GET` to the `/cards` endpoint.
-     *
-     * As opposed to `get`, this function returns all the pages of the request at once.
-     *
-     * Retrieve all cards.
-     */
-    pub async fn get_all(
-        &self,
-        user_id: &str,
-        card_program_id: &str,
-    ) -> Result<Vec<crate::types::Card>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        if !card_program_id.is_empty() {
-            query_args.push(format!("card_program_id={}", card_program_id));
-        }
-        if !user_id.is_empty() {
-            query_args.push(format!("user_id={}", user_id));
-        }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/cards?{}", query);
-
-        let mut resp: crate::types::GetCardsResponse = self.client.get(&url, None).await.unwrap();
-
-        let mut cards = resp.cards;
-        let mut page = resp.page.next;
-
-        // Paginate if we should.
-        while !page.is_empty() {
-            resp = self
-                .client
-                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
-                .await
-                .unwrap();
-
-            cards.append(&mut resp.cards);
-
-            if !resp.page.next.is_empty() && resp.page.next != page {
-                page = resp.page.next.to_string();
-            } else {
-                page = "".to_string();
-            }
-        }
-
-        // Return our response data.
-        Ok(cards)
+        self.client.get(&url, None).await
     }
 
     /**
@@ -127,7 +64,7 @@ impl Cards {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn get_card(&self, id: &str) -> Result<crate::types::Card> {
+    pub async fn get_cards(&self, id: &str) -> Result<crate::types::Card> {
         let url = format!(
             "/cards/{}",
             crate::progenitor_support::encode_path(&id.to_string()),
@@ -147,7 +84,7 @@ impl Cards {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn patch_resources_card(
+    pub async fn patch_resources(
         &self,
         id: &str,
         body: &crate::types::PatchResourcesCardsCardRequest,
@@ -158,10 +95,7 @@ impl Cards {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -176,16 +110,13 @@ impl Cards {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn post_resources_card_physical(
+    pub async fn post_resources_physical(
         &self,
         body: &crate::types::PostResourcesCardPhysicalRequest,
     ) -> Result<crate::types::TaskResponse> {
         let url = "/cards/deferred/physical".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -200,16 +131,13 @@ impl Cards {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn post_resources_card_virtual(
+    pub async fn post_resources_virtual(
         &self,
         body: &crate::types::PostResourcesCardVirtualRequest,
     ) -> Result<crate::types::TaskResponse> {
         let url = "/cards/deferred/virtual".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -220,7 +148,7 @@ impl Cards {
      *
      * Terminates a card permanently.
      */
-    pub async fn post_resources_card_termination(
+    pub async fn post_resources_termination(
         &self,
         id: &str,
         body: &crate::types::PostResourcesCardsCardSuspensionRequest,
@@ -231,10 +159,7 @@ impl Cards {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -245,7 +170,7 @@ impl Cards {
      *
      * Suspends a card so that it is locked from use. The suspension is revertable.
      */
-    pub async fn post_resources_card_suspension(
+    pub async fn post_resources_suspension(
         &self,
         id: &str,
         body: &crate::types::PostResourcesCardsCardSuspensionRequest,
@@ -256,10 +181,7 @@ impl Cards {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -270,7 +192,7 @@ impl Cards {
      *
      * Removes a card's suspension so that it may be used again.
      */
-    pub async fn post_resources_card_unsuspension(
+    pub async fn post_resources_unsuspension(
         &self,
         id: &str,
         body: &crate::types::PostResourcesCardsCardSuspensionRequest,
@@ -281,10 +203,7 @@ impl Cards {
         );
 
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
