@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Departments {
-    client: Client,
+    pub client: Client,
 }
 
 impl Departments {
@@ -22,70 +22,25 @@ impl Departments {
      * **Parameters:**
      *
      * * `authorization: &str` -- The OAuth2 token header.
-     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
-    pub async fn get_page(
+    pub async fn get(
         &self,
-        start: &str,
+        start: uuid::Uuid,
         page_size: f64,
-    ) -> Result<Vec<crate::types::Department>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        query_args.push(format!("page_size={}", page_size));
-        if !start.is_empty() {
-            query_args.push(format!("start={}", start));
+    ) -> Result<crate::types::GetDepartmentsResponse> {
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !page_size.to_string().is_empty() {
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !start.to_string().is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
-        let url = format!("/departments?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/departments?{}", query_);
 
-        let resp: crate::types::GetDepartmentsResponse = self.client.get(&url, None).await.unwrap();
-
-        // Return our response data.
-        Ok(resp.data)
-    }
-
-    /**
-     * List departments.
-     *
-     * This function performs a `GET` to the `/departments` endpoint.
-     *
-     * As opposed to `get`, this function returns all the pages of the request at once.
-     *
-     * Retrieve all departments.
-     */
-    pub async fn get_all(&self) -> Result<Vec<crate::types::Department>> {
-        let url = "/departments".to_string();
-        let mut resp: crate::types::GetDepartmentsResponse =
-            self.client.get(&url, None).await.unwrap();
-
-        let mut data = resp.data;
-        let mut page = resp.page.next;
-
-        // Paginate if we should.
-        while !page.is_empty() {
-            resp = self
-                .client
-                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
-                .await
-                .unwrap();
-
-            data.append(&mut resp.data);
-
-            if !resp.page.next.is_empty() && resp.page.next != page {
-                page = resp.page.next.to_string();
-            } else {
-                page = "".to_string();
-            }
-        }
-
-        // Return our response data.
-        Ok(data)
+        self.client.get(&url, None).await
     }
 
     /**
@@ -95,16 +50,13 @@ impl Departments {
      *
      * Create a new department.
      */
-    pub async fn post_department(
+    pub async fn post(
         &self,
         body: &crate::types::PostLocationRequest,
     ) -> Result<crate::types::Department> {
         let url = "/departments".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -119,7 +71,7 @@ impl Departments {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn get_department(&self, id: &str) -> Result<crate::types::Department> {
+    pub async fn get_departments(&self, id: &str) -> Result<crate::types::Department> {
         let url = format!(
             "/departments/{}",
             crate::progenitor_support::encode_path(&id.to_string()),
@@ -135,7 +87,7 @@ impl Departments {
      *
      * Modify a department.
      */
-    pub async fn patch_department(
+    pub async fn patch(
         &self,
         id: &str,
         body: &crate::types::PostLocationRequest,
@@ -146,10 +98,7 @@ impl Departments {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 }
