@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Receipts {
-    client: Client,
+    pub client: Client,
 }
 
 impl Receipts {
@@ -25,7 +25,7 @@ impl Receipts {
      * * `to_date: chrono::DateTime<chrono::Utc>` -- Filter for receipts related to transactions which occurred before the specified date.
      * * `created_after: chrono::DateTime<chrono::Utc>` -- Filter for receipts that were created after the specified date.
      * * `created_before: chrono::DateTime<chrono::Utc>` -- Filter for receipts that were created before the specified date.
-     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
     pub async fn get_page(
@@ -34,36 +34,32 @@ impl Receipts {
         to_date: Option<chrono::DateTime<chrono::Utc>>,
         created_after: Option<chrono::DateTime<chrono::Utc>>,
         created_before: Option<chrono::DateTime<chrono::Utc>>,
-        start: &str,
+        start: uuid::Uuid,
         page_size: f64,
     ) -> Result<Vec<crate::types::Receipt>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if let Some(date) = created_after {
-            query_args.push(format!("created_after={}", &date.to_rfc3339()));
+            query_args.push(("created_after".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = created_before {
-            query_args.push(format!("created_before={}", &date.to_rfc3339()));
+            query_args.push(("created_before".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = from_date {
-            query_args.push(format!("from_date={}", &date.to_rfc3339()));
+            query_args.push(("from_date".to_string(), date.to_rfc3339()));
         }
-        query_args.push(format!("page_size={}", page_size));
-        if !start.is_empty() {
-            query_args.push(format!("start={}", start));
+        if !page_size.to_string().is_empty() {
+            query_args.push(("page_size".to_string(), page_size.to_string()));
+        }
+        if !start.to_string().is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
         if let Some(date) = to_date {
-            query_args.push(format!("to_date={}", &date.to_rfc3339()));
+            query_args.push(("to_date".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/receipts?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/receipts?{}", query_);
 
-        let resp: crate::types::GetReceiptsResponse = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GetReceiptsResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.data)
@@ -85,48 +81,61 @@ impl Receipts {
         created_after: Option<chrono::DateTime<chrono::Utc>>,
         created_before: Option<chrono::DateTime<chrono::Utc>>,
     ) -> Result<Vec<crate::types::Receipt>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
+        let mut query_args: Vec<(String, String)> = Default::default();
         if let Some(date) = created_after {
-            query_args.push(format!("created_after={}", &date.to_rfc3339()));
+            query_args.push(("created_after".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = created_before {
-            query_args.push(format!("created_before={}", &date.to_rfc3339()));
+            query_args.push(("created_before".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = from_date {
-            query_args.push(format!("from_date={}", &date.to_rfc3339()));
+            query_args.push(("from_date".to_string(), date.to_rfc3339()));
         }
         if let Some(date) = to_date {
-            query_args.push(format!("to_date={}", &date.to_rfc3339()));
+            query_args.push(("to_date".to_string(), date.to_rfc3339()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/receipts?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/receipts?{}", query_);
 
-        let mut resp: crate::types::GetReceiptsResponse =
-            self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GetReceiptsResponse = self.client.get(&url, None).await?;
 
         let mut data = resp.data;
-        let mut page = resp.page.next;
+        let mut page = if let Some(p) = resp.page.next {
+            p.to_string()
+        } else {
+            "".to_string()
+        };
 
         // Paginate if we should.
         while !page.is_empty() {
-            resp = self
+            match self
                 .client
-                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
+                .get::<crate::types::GetReceiptsResponse>(
+                    page.trim_start_matches(crate::DEFAULT_HOST),
+                    None,
+                )
                 .await
-                .unwrap();
+            {
+                Ok(mut resp) => {
+                    data.append(&mut resp.data);
 
-            data.append(&mut resp.data);
-
-            if !resp.page.next.is_empty() && resp.page.next != page {
-                page = resp.page.next.to_string();
-            } else {
-                page = "".to_string();
+                    page = if let Some(p) = resp.page.next {
+                        if p.to_string() != page {
+                            p.to_string()
+                        } else {
+                            "".to_string()
+                        }
+                    } else {
+                        "".to_string()
+                    };
+                }
+                Err(e) => {
+                    if e.to_string().contains("404 Not Found") {
+                        page = "".to_string();
+                    } else {
+                        anyhow::bail!(e);
+                    }
+                }
             }
         }
 
@@ -141,7 +150,7 @@ impl Receipts {
      *
      *
      */
-    pub async fn get_receipt(&self, id: &str) -> Result<crate::types::Receipt> {
+    pub async fn get(&self, id: &str) -> Result<crate::types::Receipt> {
         let url = format!(
             "/receipts/{}",
             crate::progenitor_support::encode_path(&id.to_string()),
