@@ -85,7 +85,7 @@ impl Role {
 }
 
 /// Ramp User
-#[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
+#[derive(Serialize, Default, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct User {
     /**
      * The OAuth2 token header
@@ -99,12 +99,8 @@ pub struct User {
     /**
      * Ramp User
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub business_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub business_id: Option<uuid::Uuid>,
     /**
      * Ramp User
      */
@@ -133,14 +129,10 @@ pub struct User {
     )]
     pub first_name: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde()]
+    pub id: uuid::Uuid,
     /**
      * The OAuth2 token header
      */
@@ -184,60 +176,41 @@ pub struct User {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PatchUsersRequest {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub department_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub department_id: Option<uuid::Uuid>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub direct_manager_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub direct_manager_id: Option<uuid::Uuid>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub location_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub location_id: Option<uuid::Uuid>,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub role: Option<Role>,
 }
 
 #[derive(Serialize, Default, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct Page {
-    /**
-     * The OAuth2 token header
-     */
     #[serde(
         default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        skip_serializing_if = "Option::is_none",
+        deserialize_with = "crate::utils::deserialize_empty_url::deserialize"
     )]
-    pub next: String,
+    pub next: Option<url::Url>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct CardHolder {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub department_id: String,
+    #[serde()]
+    pub department_id: uuid::Uuid,
     /**
      * The OAuth2 token header
      */
@@ -266,14 +239,10 @@ pub struct CardHolder {
     )]
     pub last_name: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub location_id: String,
+    #[serde()]
+    pub location_id: uuid::Uuid,
     /**
      * The OAuth2 token header
      */
@@ -351,14 +320,10 @@ pub struct PolicyViolations {
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -422,14 +387,10 @@ pub struct Disputes {
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -449,7 +410,11 @@ pub struct Data {
     /**
      * Ramp transaction
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub accounting_categories: Vec<AccountingCategories>,
     /**
      * The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
@@ -463,28 +428,24 @@ pub struct Data {
     #[serde()]
     pub card_holder: CardHolder,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub card_id: String,
+    #[serde()]
+    pub card_id: uuid::Uuid,
     /**
      * Ramp transaction
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
-    pub disputes: Vec<Disputes>,
-    /**
-     * The OAuth2 token header
-     */
     #[serde(
         default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
     )]
-    pub id: String,
+    pub disputes: Vec<Disputes>,
+    /**
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     */
+    #[serde()]
+    pub id: uuid::Uuid,
     /**
      * Ramp transaction
      */
@@ -495,14 +456,10 @@ pub struct Data {
     )]
     pub memo: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub merchant_id: String,
+    #[serde()]
+    pub merchant_id: uuid::Uuid,
     /**
      * The OAuth2 token header
      */
@@ -515,13 +472,21 @@ pub struct Data {
     /**
      * Ramp transaction
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub policy_violations: Vec<PolicyViolations>,
     /**
      * Ramp transaction
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
-    pub receipts: Vec<String>,
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
+    pub receipts: Vec<uuid::Uuid>,
     /**
      * The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
      */
@@ -559,24 +524,37 @@ pub struct Data {
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetTransactionResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<Data>,
     #[serde(default)]
     pub page: Page,
 }
 
+#[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
+pub struct GetLocationResponsePage {
+    /**
+     * The OAuth2 token header
+     */
+    #[serde(
+        default,
+        skip_serializing_if = "String::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+    )]
+    pub next: String,
+}
+
 /// Ramp location
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct Location {
     /**
      * Ramp location
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * Ramp location
      */
@@ -590,10 +568,14 @@ pub struct Location {
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetLocationResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<Location>,
-    #[serde(default)]
-    pub page: Page,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub page: Option<GetLocationResponsePage>,
 }
 
 ///
@@ -613,7 +595,11 @@ pub struct PostLocationRequest {
 ///
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetUsersResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<User>,
     #[serde(default)]
     pub page: Page,
@@ -625,12 +611,8 @@ pub struct Department {
     /**
      * Ramp Department
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * Ramp Department
      */
@@ -644,10 +626,23 @@ pub struct Department {
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetDepartmentsResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<Department>,
-    #[serde(default)]
-    pub page: Page,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub page: Option<GetLocationResponsePage>,
+}
+
+#[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
+pub struct GetCardsResponsePage {
+    /**
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
+     */
+    #[serde()]
+    pub next: uuid::Uuid,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -658,7 +653,8 @@ pub struct RecipientAddress {
     #[serde(
         default,
         skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize",
+        rename = "address1"
     )]
     pub address_1: String,
     /**
@@ -792,12 +788,20 @@ pub struct SpendingRestrictions {
     /**
      * Specifies the spend restrictions on a Ramp card.
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub blocked_categories: Vec<f64>,
     /**
      * Specifies the spend restrictions on a Ramp card.
      */
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub categories: Vec<f64>,
     /**
      * Time interval to apply limit to.
@@ -838,21 +842,13 @@ pub struct Card {
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub card_program_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub card_program_id: Option<uuid::Uuid>,
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub cardholder_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub cardholder_id: Option<uuid::Uuid>,
     /**
      * Card data that holds mostly static information about a card.
      */
@@ -879,12 +875,8 @@ pub struct Card {
     /**
      * Card data that holds mostly static information about a card.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * Card data that holds mostly static information about a card.
      */
@@ -911,23 +903,23 @@ pub struct Card {
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetCardsResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub cards: Vec<Card>,
-    #[serde(default)]
-    pub page: Page,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub page: Option<GetCardsResponsePage>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PatchResourcesCardsCardRequest {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub card_program_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub card_program_id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -949,14 +941,10 @@ pub struct PatchResourcesCardsCardRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetCustomProviderResponse {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub custom_id_provider: String,
+    #[serde()]
+    pub custom_id_provider: uuid::Uuid,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -980,7 +968,8 @@ pub struct BillingAddress {
     #[serde(
         default,
         skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        deserialize_with = "crate::utils::deserialize_null_string::deserialize",
+        rename = "address1"
     )]
     pub address_1: String,
     /**
@@ -1137,14 +1126,10 @@ pub struct Business {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostResourcesCardPhysicalRequest {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub card_program_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub card_program_id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1174,27 +1159,19 @@ pub struct PostResourcesCardPhysicalRequest {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub spending_restrictions: Option<SpendingRestrictions>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub user_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<uuid::Uuid>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostResourcesCardVirtualRequest {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub card_program_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub card_program_id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1219,14 +1196,10 @@ pub struct PostResourcesCardVirtualRequest {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub spending_restrictions: Option<SpendingRestrictions>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub user_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<uuid::Uuid>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1337,12 +1310,20 @@ pub struct BusinessCurrentStatus {
     /**
      * Current data about the business.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
+    #[serde(
+        default,
+        skip_serializing_if = "Option::is_none",
+        deserialize_with = "crate::utils::date_format::deserialize"
+    )]
     pub next_billing_date: Option<chrono::NaiveDate>,
     /**
      * Current data about the business.
      */
-    #[serde(default, skip_serializing_if = "Option::is_none")]
+    #[serde(
+        default,
+        skip_serializing_if = "Option::is_none",
+        deserialize_with = "crate::utils::date_format::deserialize"
+    )]
     pub prev_billing_date: Option<chrono::NaiveDate>,
     /**
      * Current data about the business.
@@ -1371,14 +1352,10 @@ pub struct PostResourcesCardsCardSuspensionRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetEntityTypeCustomRampResponse {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub ramp_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub ramp_id: Option<uuid::Uuid>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1415,14 +1392,10 @@ pub struct GetResourcesCardsDeferredResponseData {
     )]
     pub error: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1480,14 +1453,10 @@ pub struct GetResourcesCardsDeferredResponse {
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub data: Option<GetResourcesCardsDeferredResponseData>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     #[serde(default, skip_serializing_if = "Option::is_none")]
     pub status: Option<Status>,
 }
@@ -1580,12 +1549,8 @@ pub struct CardProgram {
     /**
      * Card Program data that serves as a template for creating new cards.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * Card Program data that serves as a template for creating new cards.
      */
@@ -1611,10 +1576,15 @@ pub struct CardProgram {
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetCardProgramsResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize",
+        rename = "card-programs"
+    )]
     pub card_programs: Vec<CardProgram>,
-    #[serde(default)]
-    pub page: Page,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub page: Option<GetCardsResponsePage>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
@@ -1653,23 +1623,15 @@ pub struct PostResourcesCardProgramRequest {
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct PostUsersDeferredRequest {
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub department_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub department_id: Option<uuid::Uuid>,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub direct_manager_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub direct_manager_id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1698,14 +1660,10 @@ pub struct PostUsersDeferredRequest {
     )]
     pub last_name: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub location_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub location_id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1731,14 +1689,10 @@ pub struct GetUsersDeferredStatusResponseData {
     )]
     pub error: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     /**
      * The OAuth2 token header
      */
@@ -1749,14 +1703,10 @@ pub struct GetUsersDeferredStatusResponseData {
     )]
     pub misc: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub user_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<uuid::Uuid>,
 }
 
 ///
@@ -1805,35 +1755,27 @@ pub struct Receipt {
         deserialize_with = "crate::utils::date_time_format::deserialize"
     )]
     pub created_at: Option<chrono::DateTime<chrono::Utc>>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     #[serde(
         default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        skip_serializing_if = "Option::is_none",
+        deserialize_with = "crate::utils::deserialize_empty_url::deserialize"
     )]
-    pub id: String,
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub receipt_url: String,
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub transaction_id: String,
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub user_id: String,
+    pub receipt_url: Option<url::Url>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub transaction_id: Option<uuid::Uuid>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<uuid::Uuid>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetReceiptsResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<Receipt>,
     #[serde(default)]
     pub page: Page,
@@ -1859,33 +1801,37 @@ pub struct Reimbursement {
         deserialize_with = "crate::utils::deserialize_null_string::deserialize"
     )]
     pub currency: String,
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub id: Option<uuid::Uuid>,
     #[serde(
         default,
         skip_serializing_if = "String::is_empty",
         deserialize_with = "crate::utils::deserialize_null_string::deserialize"
     )]
     pub merchant: String,
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
-    pub receipts: Vec<String>,
-    #[serde(default, skip_serializing_if = "Option::is_none")]
-    pub transaction_date: Option<chrono::NaiveDate>,
     #[serde(
         default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
     )]
-    pub user_id: String,
+    pub receipts: Vec<uuid::Uuid>,
+    #[serde(
+        default,
+        skip_serializing_if = "Option::is_none",
+        deserialize_with = "crate::utils::date_format::deserialize"
+    )]
+    pub transaction_date: Option<chrono::NaiveDate>,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub user_id: Option<uuid::Uuid>,
 }
 
 #[derive(Serialize, Deserialize, PartialEq, Debug, Clone, JsonSchema)]
 pub struct GetReimbursementsResponse {
-    #[serde(default, skip_serializing_if = "Vec::is_empty")]
+    #[serde(
+        default,
+        skip_serializing_if = "Vec::is_empty",
+        deserialize_with = "crate::utils::deserialize_null_vector::deserialize"
+    )]
     pub data: Vec<Reimbursement>,
     #[serde(default)]
     pub page: Page,
@@ -1903,12 +1849,8 @@ pub struct PostCustomProviderEntityTypeLinkRequest {
     )]
     pub custom_id: String,
     /**
-     * The OAuth2 token header
+     * The ID of the last entity of the previous page, used for pagination to get the next page.
      */
-    #[serde(
-        default,
-        skip_serializing_if = "String::is_empty",
-        deserialize_with = "crate::utils::deserialize_null_string::deserialize"
-    )]
-    pub ramp_id: String,
+    #[serde(default, skip_serializing_if = "Option::is_none")]
+    pub ramp_id: Option<uuid::Uuid>,
 }
