@@ -3,7 +3,7 @@ use anyhow::Result;
 use crate::Client;
 
 pub struct Users {
-    client: Client,
+    pub client: Client,
 }
 
 impl Users {
@@ -23,7 +23,7 @@ impl Users {
      *
      * * `authorization: &str` -- The OAuth2 token header.
      */
-    pub async fn get_user(&self, id: &str) -> Result<crate::types::User> {
+    pub async fn get(&self, id: &str) -> Result<crate::types::User> {
         let url = format!(
             "/users/{}",
             crate::progenitor_support::encode_path(&id.to_string()),
@@ -62,10 +62,7 @@ impl Users {
         );
 
         self.client
-            .patch(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .patch(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
@@ -79,39 +76,35 @@ impl Users {
      * **Parameters:**
      *
      * * `authorization: &str` -- The OAuth2 token header.
-     * * `start: &str` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `start: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      * * `page_size: f64` -- The number of results to be returned in each page. The value must be between 2 and 10,000. If not specified, the default will be 1,000.
-     * * `department_id: &str` -- The OAuth2 token header.
-     * * `location_id: &str` -- The OAuth2 token header.
+     * * `department_id: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
+     * * `location_id: uuid::Uuid` -- The ID of the last entity of the previous page, used for pagination to get the next page.
      */
     pub async fn get_page(
         &self,
-        start: &str,
+        start: uuid::Uuid,
         page_size: f64,
-        department_id: &str,
-        location_id: &str,
+        department_id: uuid::Uuid,
+        location_id: uuid::Uuid,
     ) -> Result<Vec<crate::types::User>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        if !department_id.is_empty() {
-            query_args.push(format!("department_id={}", department_id));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !department_id.to_string().is_empty() {
+            query_args.push(("department_id".to_string(), department_id.to_string()));
         }
-        if !location_id.is_empty() {
-            query_args.push(format!("location_id={}", location_id));
+        if !location_id.to_string().is_empty() {
+            query_args.push(("location_id".to_string(), location_id.to_string()));
         }
-        query_args.push(format!("page_size={}", page_size));
-        if !start.is_empty() {
-            query_args.push(format!("start={}", start));
+        if !page_size.to_string().is_empty() {
+            query_args.push(("page_size".to_string(), page_size.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
+        if !start.to_string().is_empty() {
+            query_args.push(("start".to_string(), start.to_string()));
         }
-        let url = format!("/users?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users?{}", query_);
 
-        let resp: crate::types::GetUsersResponse = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GetUsersResponse = self.client.get(&url, None).await?;
 
         // Return our response data.
         Ok(resp.data)
@@ -128,44 +121,58 @@ impl Users {
      */
     pub async fn get_all(
         &self,
-        department_id: &str,
-        location_id: &str,
+        department_id: uuid::Uuid,
+        location_id: uuid::Uuid,
     ) -> Result<Vec<crate::types::User>> {
-        let mut query = String::new();
-        let mut query_args: Vec<String> = Default::default();
-        if !department_id.is_empty() {
-            query_args.push(format!("department_id={}", department_id));
+        let mut query_args: Vec<(String, String)> = Default::default();
+        if !department_id.to_string().is_empty() {
+            query_args.push(("department_id".to_string(), department_id.to_string()));
         }
-        if !location_id.is_empty() {
-            query_args.push(format!("location_id={}", location_id));
+        if !location_id.to_string().is_empty() {
+            query_args.push(("location_id".to_string(), location_id.to_string()));
         }
-        for (i, n) in query_args.iter().enumerate() {
-            if i > 0 {
-                query.push('&');
-            }
-            query.push_str(n);
-        }
-        let url = format!("/users?{}", query);
+        let query_ = serde_urlencoded::to_string(&query_args).unwrap();
+        let url = format!("/users?{}", query_);
 
-        let mut resp: crate::types::GetUsersResponse = self.client.get(&url, None).await.unwrap();
+        let resp: crate::types::GetUsersResponse = self.client.get(&url, None).await?;
 
         let mut data = resp.data;
-        let mut page = resp.page.next;
+        let mut page = if let Some(p) = resp.page.next {
+            p.to_string()
+        } else {
+            "".to_string()
+        };
 
         // Paginate if we should.
         while !page.is_empty() {
-            resp = self
+            match self
                 .client
-                .get(page.trim_start_matches(crate::DEFAULT_HOST), None)
+                .get::<crate::types::GetUsersResponse>(
+                    page.trim_start_matches(crate::DEFAULT_HOST),
+                    None,
+                )
                 .await
-                .unwrap();
+            {
+                Ok(mut resp) => {
+                    data.append(&mut resp.data);
 
-            data.append(&mut resp.data);
-
-            if !resp.page.next.is_empty() && resp.page.next != page {
-                page = resp.page.next.to_string();
-            } else {
-                page = "".to_string();
+                    page = if let Some(p) = resp.page.next {
+                        if p.to_string() != page {
+                            p.to_string()
+                        } else {
+                            "".to_string()
+                        }
+                    } else {
+                        "".to_string()
+                    };
+                }
+                Err(e) => {
+                    if e.to_string().contains("404 Not Found") {
+                        page = "".to_string();
+                    } else {
+                        anyhow::bail!(e);
+                    }
+                }
             }
         }
 
@@ -186,10 +193,7 @@ impl Users {
     ) -> Result<crate::types::User> {
         let url = "/users/deferred".to_string();
         self.client
-            .post(
-                &url,
-                Some(reqwest::Body::from(serde_json::to_vec(body).unwrap())),
-            )
+            .post(&url, Some(reqwest::Body::from(serde_json::to_vec(body)?)))
             .await
     }
 
